==> zio-aws-ec2_2.13-5.17.102.9-sources.jar: zio/aws/ec2/model/CreateTransitGatewayPrefixListReferenceResponse.scala <==
package zio.aws.ec2.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class CreateTransitGatewayPrefixListReferenceResponse(
    transitGatewayPrefixListReference: Option[
      zio.aws.ec2.model.TransitGatewayPrefixListReference
    ] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.ec2.model.CreateTransitGatewayPrefixListReferenceResponse = {
    import CreateTransitGatewayPrefixListReferenceResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.ec2.model.CreateTransitGatewayPrefixListReferenceResponse
      .builder()
      .optionallyWith(
        transitGatewayPrefixListReference.map(value => value.buildAwsValue())
      )(_.transitGatewayPrefixListReference)
      .build()
  }
  def asReadOnly
      : zio.aws.ec2.model.CreateTransitGatewayPrefixListReferenceResponse.ReadOnly =
    zio.aws.ec2.model.CreateTransitGatewayPrefixListReferenceResponse
      .wrap(buildAwsValue())
}
object CreateTransitGatewayPrefixListReferenceResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.ec2.model.CreateTransitGatewayPrefixListReferenceResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.ec2.model.CreateTransitGatewayPrefixListReferenceResponse =
      zio.aws.ec2.model.CreateTransitGatewayPrefixListReferenceResponse(
        transitGatewayPrefixListReference.map(value => value.asEditable)
      )
    def transitGatewayPrefixListReference
        : Option[zio.aws.ec2.model.TransitGatewayPrefixListReference.ReadOnly]
    def getTransitGatewayPrefixListReference: ZIO[
      Any,
      AwsError,
      zio.aws.ec2.model.TransitGatewayPrefixListReference.ReadOnly
    ] = AwsError.unwrapOptionField(
      "transitGatewayPrefixListReference",
      transitGatewayPrefixListReference
    )
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.ec2.model.CreateTransitGatewayPrefixListReferenceResponse
  ) extends zio.aws.ec2.model.CreateTransitGatewayPrefixListReferenceResponse.ReadOnly {
    override val transitGatewayPrefixListReference
        : Option[zio.aws.ec2.model.TransitGatewayPrefixListReference.ReadOnly] =
      scala
        .Option(impl.transitGatewayPrefixListReference())
        .map(value =>
          zio.aws.ec2.model.TransitGatewayPrefixListReference.wrap(value)
        )
  }
  def wrap(
      impl: software.amazon.awssdk.services.ec2.model.CreateTransitGatewayPrefixListReferenceResponse
  ): zio.aws.ec2.model.CreateTransitGatewayPrefixListReferenceResponse.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-ec2_2.13-6.20.78.2-sources.jar: zio/aws/ec2/model/CreateTransitGatewayPrefixListReferenceResponse.scala <==
package zio.aws.ec2.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class CreateTransitGatewayPrefixListReferenceResponse(
    transitGatewayPrefixListReference: Optional[
      zio.aws.ec2.model.TransitGatewayPrefixListReference
    ] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.ec2.model.CreateTransitGatewayPrefixListReferenceResponse = {
    import CreateTransitGatewayPrefixListReferenceResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.ec2.model.CreateTransitGatewayPrefixListReferenceResponse
      .builder()
      .optionallyWith(
        transitGatewayPrefixListReference.map(value => value.buildAwsValue())
      )(_.transitGatewayPrefixListReference)
      .build()
  }
  def asReadOnly
      : zio.aws.ec2.model.CreateTransitGatewayPrefixListReferenceResponse.ReadOnly =
    zio.aws.ec2.model.CreateTransitGatewayPrefixListReferenceResponse
      .wrap(buildAwsValue())
}
object CreateTransitGatewayPrefixListReferenceResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.ec2.model.CreateTransitGatewayPrefixListReferenceResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.ec2.model.CreateTransitGatewayPrefixListReferenceResponse =
      zio.aws.ec2.model.CreateTransitGatewayPrefixListReferenceResponse(
        transitGatewayPrefixListReference.map(value => value.asEditable)
      )
    def transitGatewayPrefixListReference
        : Optional[zio.aws.ec2.model.TransitGatewayPrefixListReference.ReadOnly]
    def getTransitGatewayPrefixListReference: ZIO[
      Any,
      AwsError,
      zio.aws.ec2.model.TransitGatewayPrefixListReference.ReadOnly
    ] = AwsError.unwrapOptionField(
      "transitGatewayPrefixListReference",
      transitGatewayPrefixListReference
    )
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.ec2.model.CreateTransitGatewayPrefixListReferenceResponse
  ) extends zio.aws.ec2.model.CreateTransitGatewayPrefixListReferenceResponse.ReadOnly {
    override val transitGatewayPrefixListReference: Optional[
      zio.aws.ec2.model.TransitGatewayPrefixListReference.ReadOnly
    ] = zio.aws.core.internal
      .optionalFromNullable(impl.transitGatewayPrefixListReference())
      .map(value =>
        zio.aws.ec2.model.TransitGatewayPrefixListReference.wrap(value)
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.ec2.model.CreateTransitGatewayPrefixListReferenceResponse
  ): zio.aws.ec2.model.CreateTransitGatewayPrefixListReferenceResponse.ReadOnly =
    new Wrapper(impl)
}
